@@ -20,9 +20,7 @@ class TimeoutExpired(DvcTaskError):
     """Process timeout expired."""
 
     def __init__(self, cmd, timeout):
-        super().__init__(
-            f"'{cmd}' did not complete before timeout '{timeout}'"
-        )
+        super().__init__(f"'{cmd}' did not complete before timeout '{timeout}'")
         self.cmd = cmd
         self.timeout = timeout
 
